from queryservice_client.protobuf.common import auth_pb2 as _auth_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ArrayOfTextParam(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, key: _Optional[str] = ..., value: _Optional[_Iterable[str]] = ...) -> None: ...

class BooleanParam(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: bool
    def __init__(self, key: _Optional[str] = ..., value: bool = ...) -> None: ...

class DictionaryParam(_message.Message):
    __slots__ = ("key", "value")
    class ValueEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: _containers.ScalarMap[str, str]
    def __init__(self, key: _Optional[str] = ..., value: _Optional[_Mapping[str, str]] = ...) -> None: ...

class EncryptedBinaryParam(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: bytes
    def __init__(self, key: _Optional[str] = ..., value: _Optional[bytes] = ...) -> None: ...

class EncryptedTextParam(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class FloatParam(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: float
    def __init__(self, key: _Optional[str] = ..., value: _Optional[float] = ...) -> None: ...

class IntegerParam(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: int
    def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...

class RadioParam(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class SelectParam(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class TextParam(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class TextAreaParam(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class AuthParam(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: _auth_pb2.Auth
    def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_auth_pb2.Auth, _Mapping]] = ...) -> None: ...

class ProtobufParameter(_message.Message):
    __slots__ = ("arrayOfText", "boolean", "dictionary", "encryptedBinary", "encryptedText", "float", "integer", "text", "textArea", "radio", "select", "auth")
    ARRAYOFTEXT_FIELD_NUMBER: _ClassVar[int]
    BOOLEAN_FIELD_NUMBER: _ClassVar[int]
    DICTIONARY_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTEDBINARY_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTEDTEXT_FIELD_NUMBER: _ClassVar[int]
    FLOAT_FIELD_NUMBER: _ClassVar[int]
    INTEGER_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    TEXTAREA_FIELD_NUMBER: _ClassVar[int]
    RADIO_FIELD_NUMBER: _ClassVar[int]
    SELECT_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    arrayOfText: ArrayOfTextParam
    boolean: BooleanParam
    dictionary: DictionaryParam
    encryptedBinary: EncryptedBinaryParam
    encryptedText: EncryptedTextParam
    float: FloatParam
    integer: IntegerParam
    text: TextParam
    textArea: TextAreaParam
    radio: RadioParam
    select: SelectParam
    auth: AuthParam
    def __init__(self, arrayOfText: _Optional[_Union[ArrayOfTextParam, _Mapping]] = ..., boolean: _Optional[_Union[BooleanParam, _Mapping]] = ..., dictionary: _Optional[_Union[DictionaryParam, _Mapping]] = ..., encryptedBinary: _Optional[_Union[EncryptedBinaryParam, _Mapping]] = ..., encryptedText: _Optional[_Union[EncryptedTextParam, _Mapping]] = ..., float: _Optional[_Union[FloatParam, _Mapping]] = ..., integer: _Optional[_Union[IntegerParam, _Mapping]] = ..., text: _Optional[_Union[TextParam, _Mapping]] = ..., textArea: _Optional[_Union[TextAreaParam, _Mapping]] = ..., radio: _Optional[_Union[RadioParam, _Mapping]] = ..., select: _Optional[_Union[SelectParam, _Mapping]] = ..., auth: _Optional[_Union[AuthParam, _Mapping]] = ...) -> None: ...

class ProtobufConfiguration(_message.Message):
    __slots__ = ("parameters", "interpolatedParameters")
    class ParametersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: ProtobufParameter
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[ProtobufParameter, _Mapping]] = ...) -> None: ...
    class InterpolatedParametersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _auth_pb2.CAGRequest
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_auth_pb2.CAGRequest, _Mapping]] = ...) -> None: ...
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    INTERPOLATEDPARAMETERS_FIELD_NUMBER: _ClassVar[int]
    parameters: _containers.MessageMap[str, ProtobufParameter]
    interpolatedParameters: _containers.MessageMap[str, _auth_pb2.CAGRequest]
    def __init__(self, parameters: _Optional[_Mapping[str, ProtobufParameter]] = ..., interpolatedParameters: _Optional[_Mapping[str, _auth_pb2.CAGRequest]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SourceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    None: _ClassVar[SourceType]
    RDBMS: _ClassVar[SourceType]
    BI: _ClassVar[SourceType]
    FS: _ClassVar[SourceType]
None: SourceType
RDBMS: SourceType
BI: SourceType
FS: SourceType

class ConnectionInfo(_message.Message):
    __slots__ = ("uri", "host", "port")
    URI_FIELD_NUMBER: _ClassVar[int]
    HOST_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    uri: str
    host: str
    port: int
    def __init__(self, uri: _Optional[str] = ..., host: _Optional[str] = ..., port: _Optional[int] = ...) -> None: ...

class Self(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DataSource(_message.Message):
    __slots__ = ("type", "self", "id", "connection")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SELF_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_FIELD_NUMBER: _ClassVar[int]
    type: SourceType
    self: Self
    id: int
    connection: ConnectionInfo
    def __init__(self, type: _Optional[_Union[SourceType, str]] = ..., self: _Optional[_Union[Self, _Mapping]] = ..., id: _Optional[int] = ..., connection: _Optional[_Union[ConnectionInfo, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: policy/policy_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bpolicy/policy_objects.proto\x12\x19ocf.policy.policy_objects\x1a\x17rdbms/mde_objects.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x19\n\x08PolicyId\x12\r\n\x05parts\x18\x01 \x03(\t\"w\n\x0bPolicyApiId\x12<\n\x03key\x18\x01 \x03(\x0b\x32/.ocf.policy.policy_objects.PolicyApiId.KeyEntry\x1a*\n\x08KeyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\rSQLDefinition\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x03(\t\"\xec\x02\n\x06Policy\x12/\n\x02id\x18\x01 \x01(\x0b\x32#.ocf.policy.policy_objects.PolicyId\x12\x35\n\x05\x61piId\x18\x02 \x01(\x0b\x32&.ocf.policy.policy_objects.PolicyApiId\x12\x0c\n\x04name\x18\x03 \x01(\t\x12@\n\npolicyType\x18\x04 \x01(\x0e\x32,.ocf.policy.policy_objects.Policy.PolicyType\x12\r\n\x05owner\x18\x05 \x01(\t\x12-\n\ttsCreated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\rsqlDefinition\x18\x07 \x01(\x0b\x32(.ocf.policy.policy_objects.SQLDefinition\"+\n\nPolicyType\x12\r\n\tDATA_MASK\x10\x00\x12\x0e\n\nROW_ACCESS\x10\x01\"j\n\tTableLink\x12\x30\n\x03pid\x18\x01 \x01(\x0b\x32#.ocf.policy.policy_objects.PolicyId\x12+\n\x07tableId\x18\x02 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableId\"m\n\nColumnLink\x12\x30\n\x03pid\x18\x01 \x01(\x0b\x32#.ocf.policy.policy_objects.PolicyId\x12-\n\x08\x63olumnId\x18\x02 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\"\x8e\x01\n\x11PolicyObjectApiId\x12\x33\n\ntableApiId\x18\x01 \x01(\x0b\x32\x1d.rdbms.mde_objects.TableApiIdH\x00\x12\x35\n\x0b\x63olumnApiId\x18\x02 \x01(\x0b\x32\x1e.rdbms.mde_objects.ColumnApiIdH\x00\x42\r\n\x0bobjectApiId\"Q\n\x0ePolicyArgument\x12\x10\n\x08\x61rgument\x18\x01 \x01(\t\x12-\n\x08\x63olumnId\x18\x02 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\"\xa4\x01\n\x15PolicyObjectSyncValue\x12G\n\x11policyObjectApiId\x18\x01 \x01(\x0b\x32,.ocf.policy.policy_objects.PolicyObjectApiId\x12\x42\n\x0fpolicyArguments\x18\x02 \x03(\x0b\x32).ocf.policy.policy_objects.PolicyArgumentB:\n\x1f\x61lation.sdk.ocf.policy.grpc.mdeB\x15PolicyMetadataObjectsP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'policy.policy_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037alation.sdk.ocf.policy.grpc.mdeB\025PolicyMetadataObjectsP\001'
  _globals['_POLICYAPIID_KEYENTRY']._options = None
  _globals['_POLICYAPIID_KEYENTRY']._serialized_options = b'8\001'
  _globals['_POLICYID']._serialized_start=116
  _globals['_POLICYID']._serialized_end=141
  _globals['_POLICYAPIID']._serialized_start=143
  _globals['_POLICYAPIID']._serialized_end=262
  _globals['_POLICYAPIID_KEYENTRY']._serialized_start=220
  _globals['_POLICYAPIID_KEYENTRY']._serialized_end=262
  _globals['_SQLDEFINITION']._serialized_start=264
  _globals['_SQLDEFINITION']._serialized_end=311
  _globals['_POLICY']._serialized_start=314
  _globals['_POLICY']._serialized_end=678
  _globals['_POLICY_POLICYTYPE']._serialized_start=635
  _globals['_POLICY_POLICYTYPE']._serialized_end=678
  _globals['_TABLELINK']._serialized_start=680
  _globals['_TABLELINK']._serialized_end=786
  _globals['_COLUMNLINK']._serialized_start=788
  _globals['_COLUMNLINK']._serialized_end=897
  _globals['_POLICYOBJECTAPIID']._serialized_start=900
  _globals['_POLICYOBJECTAPIID']._serialized_end=1042
  _globals['_POLICYARGUMENT']._serialized_start=1044
  _globals['_POLICYARGUMENT']._serialized_end=1125
  _globals['_POLICYOBJECTSYNCVALUE']._serialized_start=1128
  _globals['_POLICYOBJECTSYNCVALUE']._serialized_end=1292
# @@protoc_insertion_point(module_scope)



from typing import Optional
from queryservice_client.stream.segments.resultset import ResultSet
from queryservice_client.stream.resultsetstream import ResultSetStream
from queryservice_client.stream.stream import Stream

class Statement():
    def __init__(self, stream: Stream, cancel_function):
        self.stream = stream
        self.current: Optional[ResultSetStream] = None
        self.cancel_function = cancel_function

    def __iter__(self):
        return self

    def __next__(self):
        while not next(self.stream).HasField("beginResultSet"):
            pass
        self.current = ResultSetStream(self.stream)
        return ResultSet(self.current)

    def has_next(self):
        if not self.stream.has_next():
            return False
        if self.current:
            while self.current.has_next():
                next(self.current)
            self.current = None
        return self.stream.has_next()

    def cancel(self):
        self.cancel_function()


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bi/mde.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2
from bi import mde_objects_pb2 as bi_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x62i/mde.proto\x12\x06\x62i.mde\x1a\x1a\x63ommon/configuration.proto\x1a\x16\x63ommon/job_error.proto\x1a\x14\x62i/mde_objects.proto\"y\n\x15ListFileSystemRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12*\n\x05users\x18\x02 \x03(\x0b\x32\x1b.bi.mde_objects.AlationUser\"\xc3\x01\n\x18RunFullExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12,\n\x07\x66olders\x18\x02 \x03(\x0b\x32\x1b.bi.mde_objects.GBMBIFolder\x12\x17\n\x0fisIncludeFilter\x18\x03 \x01(\x08\x12*\n\x05users\x18\x04 \x03(\x0b\x32\x1b.bi.mde_objects.AlationUser\"\xf9\x04\n\x10\x42IObjectResponse\x12+\n\x06\x62iUser\x18\x01 \x01(\x0b\x32\x19.bi.mde_objects.GBMBIUserH\x00\x12/\n\x08\x62iFolder\x18\x02 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIFolderH\x00\x12/\n\x08\x62iReport\x18\x03 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIReportH\x00\x12\x37\n\x0c\x62iDataSource\x18\x04 \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIDatasourceH\x00\x12\x37\n\x0c\x62iConnection\x18\x05 \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIConnectionH\x00\x12;\n\x0e\x62iReportColumn\x18\x06 \x01(\x0b\x32!.bi.mde_objects.GBMBIReportColumnH\x00\x12\x43\n\x12\x62iDatasourceColumn\x18\x07 \x01(\x0b\x32%.bi.mde_objects.GBMBIDatasourceColumnH\x00\x12\x43\n\x12\x62iConnectionColumn\x18\x08 \x01(\x0b\x32%.bi.mde_objects.GBMBIConnectionColumnH\x00\x12\x37\n\x0c\x62iPermission\x18\t \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIPermissionH\x00\x12-\n\x07\x62iImage\x18\n \x01(\x0b\x32\x1a.bi.mde_objects.GBMBIImageH\x00\x12!\n\x05\x65rror\x18\x0b \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x12\n\x10\x62iObjectResponseB/\n\x17\x61lation.sdk.bi.grpc.mdeB\x12MetadataExtractionP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bi.mde_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.bi.grpc.mdeB\022MetadataExtractionP\001'
  _globals['_LISTFILESYSTEMREQUEST']._serialized_start=98
  _globals['_LISTFILESYSTEMREQUEST']._serialized_end=219
  _globals['_RUNFULLEXTRACTIONREQUEST']._serialized_start=222
  _globals['_RUNFULLEXTRACTIONREQUEST']._serialized_end=417
  _globals['_BIOBJECTRESPONSE']._serialized_start=420
  _globals['_BIOBJECTRESPONSE']._serialized_end=1053
# @@protoc_insertion_point(module_scope)



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.common import auth_pb2 as _auth_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DataType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NULL: _ClassVar[DataType]
    DOUBLE: _ClassVar[DataType]
    FLOAT: _ClassVar[DataType]
    INT32: _ClassVar[DataType]
    INT64: _ClassVar[DataType]
    UINT32: _ClassVar[DataType]
    UINT64: _ClassVar[DataType]
    BOOL: _ClassVar[DataType]
    STRING: _ClassVar[DataType]
    BYTES: _ClassVar[DataType]
    DATE: _ClassVar[DataType]
    ARRAY: _ClassVar[DataType]
    STRUCT: _ClassVar[DataType]
    BIGINT: _ClassVar[DataType]
    BIGDECIMAL: _ClassVar[DataType]

class Endianness(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    BIG: _ClassVar[Endianness]
    LITTLE: _ClassVar[Endianness]
NULL: DataType
DOUBLE: DataType
FLOAT: DataType
INT32: DataType
INT64: DataType
UINT32: DataType
UINT64: DataType
BOOL: DataType
STRING: DataType
BYTES: DataType
DATE: DataType
ARRAY: DataType
STRUCT: DataType
BIGINT: DataType
BIGDECIMAL: DataType
BIG: Endianness
LITTLE: Endianness

class StartSessionRequest(_message.Message):
    __slots__ = ("configuration", "authentication")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATION_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    authentication: _auth_pb2.Auth
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., authentication: _Optional[_Union[_auth_pb2.Auth, _Mapping]] = ...) -> None: ...

class StartSessionResponse(_message.Message):
    __slots__ = ("sessionId", "supportsCancellation")
    SESSIONID_FIELD_NUMBER: _ClassVar[int]
    SUPPORTSCANCELLATION_FIELD_NUMBER: _ClassVar[int]
    sessionId: int
    supportsCancellation: bool
    def __init__(self, sessionId: _Optional[int] = ..., supportsCancellation: bool = ...) -> None: ...

class EndSessionRequest(_message.Message):
    __slots__ = ("sessionId",)
    SESSIONID_FIELD_NUMBER: _ClassVar[int]
    sessionId: int
    def __init__(self, sessionId: _Optional[int] = ...) -> None: ...

class CancelQueryRequest(_message.Message):
    __slots__ = ("sessionId",)
    SESSIONID_FIELD_NUMBER: _ClassVar[int]
    sessionId: int
    def __init__(self, sessionId: _Optional[int] = ...) -> None: ...

class CancelQueryResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryRequest(_message.Message):
    __slots__ = ("sessionId", "query", "limit", "timeout")
    SESSIONID_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    sessionId: int
    query: str
    limit: int
    timeout: int
    def __init__(self, sessionId: _Optional[int] = ..., query: _Optional[str] = ..., limit: _Optional[int] = ..., timeout: _Optional[int] = ...) -> None: ...

class QueryResponse(_message.Message):
    __slots__ = ("restart", "cancelled", "queryResult")
    RESTART_FIELD_NUMBER: _ClassVar[int]
    CANCELLED_FIELD_NUMBER: _ClassVar[int]
    QUERYRESULT_FIELD_NUMBER: _ClassVar[int]
    restart: bool
    cancelled: bool
    queryResult: QueryResult
    def __init__(self, restart: bool = ..., cancelled: bool = ..., queryResult: _Optional[_Union[QueryResult, _Mapping]] = ...) -> None: ...

class QueryResult(_message.Message):
    __slots__ = ("objects",)
    OBJECTS_FIELD_NUMBER: _ClassVar[int]
    objects: _containers.RepeatedCompositeFieldContainer[QueryResultObject]
    def __init__(self, objects: _Optional[_Iterable[_Union[QueryResultObject, _Mapping]]] = ...) -> None: ...

class QueryResultObject(_message.Message):
    __slots__ = ("data", "beginResultSet", "endOfResultSet", "endOfMetadata", "endOfRow")
    DATA_FIELD_NUMBER: _ClassVar[int]
    BEGINRESULTSET_FIELD_NUMBER: _ClassVar[int]
    ENDOFRESULTSET_FIELD_NUMBER: _ClassVar[int]
    ENDOFMETADATA_FIELD_NUMBER: _ClassVar[int]
    ENDOFROW_FIELD_NUMBER: _ClassVar[int]
    data: StreamData
    beginResultSet: StreamDelimiter
    endOfResultSet: StreamDelimiter
    endOfMetadata: StreamDelimiter
    endOfRow: StreamDelimiter
    def __init__(self, data: _Optional[_Union[StreamData, _Mapping]] = ..., beginResultSet: _Optional[_Union[StreamDelimiter, _Mapping]] = ..., endOfResultSet: _Optional[_Union[StreamDelimiter, _Mapping]] = ..., endOfMetadata: _Optional[_Union[StreamDelimiter, _Mapping]] = ..., endOfRow: _Optional[_Union[StreamDelimiter, _Mapping]] = ...) -> None: ...

class StreamData(_message.Message):
    __slots__ = ("metadata", "rowData")
    METADATA_FIELD_NUMBER: _ClassVar[int]
    ROWDATA_FIELD_NUMBER: _ClassVar[int]
    metadata: Metadata
    rowData: RowData
    def __init__(self, metadata: _Optional[_Union[Metadata, _Mapping]] = ..., rowData: _Optional[_Union[RowData, _Mapping]] = ...) -> None: ...

class Metadata(_message.Message):
    __slots__ = ("projection", "updateCount")
    PROJECTION_FIELD_NUMBER: _ClassVar[int]
    UPDATECOUNT_FIELD_NUMBER: _ClassVar[int]
    projection: Projection
    updateCount: int
    def __init__(self, projection: _Optional[_Union[Projection, _Mapping]] = ..., updateCount: _Optional[int] = ...) -> None: ...

class Projection(_message.Message):
    __slots__ = ("name", "ordinality", "type", "dtype", "label")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ORDINALITY_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DTYPE_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    name: str
    ordinality: int
    type: str
    dtype: DataType
    label: str
    def __init__(self, name: _Optional[str] = ..., ordinality: _Optional[int] = ..., type: _Optional[str] = ..., dtype: _Optional[_Union[DataType, str]] = ..., label: _Optional[str] = ...) -> None: ...

class RowData(_message.Message):
    __slots__ = ("null", "double", "float", "int32", "int64", "uint32", "uint64", "bool", "string", "bytes", "date", "array", "struct", "bigInt", "bigDecimal")
    NULL_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_FIELD_NUMBER: _ClassVar[int]
    FLOAT_FIELD_NUMBER: _ClassVar[int]
    INT32_FIELD_NUMBER: _ClassVar[int]
    INT64_FIELD_NUMBER: _ClassVar[int]
    UINT32_FIELD_NUMBER: _ClassVar[int]
    UINT64_FIELD_NUMBER: _ClassVar[int]
    BOOL_FIELD_NUMBER: _ClassVar[int]
    STRING_FIELD_NUMBER: _ClassVar[int]
    BYTES_FIELD_NUMBER: _ClassVar[int]
    DATE_FIELD_NUMBER: _ClassVar[int]
    ARRAY_FIELD_NUMBER: _ClassVar[int]
    STRUCT_FIELD_NUMBER: _ClassVar[int]
    BIGINT_FIELD_NUMBER: _ClassVar[int]
    BIGDECIMAL_FIELD_NUMBER: _ClassVar[int]
    null: Null
    double: float
    float: float
    int32: int
    int64: int
    uint32: int
    uint64: int
    bool: bool
    string: str
    bytes: bytes
    date: Date
    array: Array
    struct: Struct
    bigInt: BigInt
    bigDecimal: BigDecimal
    def __init__(self, null: _Optional[_Union[Null, _Mapping]] = ..., double: _Optional[float] = ..., float: _Optional[float] = ..., int32: _Optional[int] = ..., int64: _Optional[int] = ..., uint32: _Optional[int] = ..., uint64: _Optional[int] = ..., bool: bool = ..., string: _Optional[str] = ..., bytes: _Optional[bytes] = ..., date: _Optional[_Union[Date, _Mapping]] = ..., array: _Optional[_Union[Array, _Mapping]] = ..., struct: _Optional[_Union[Struct, _Mapping]] = ..., bigInt: _Optional[_Union[BigInt, _Mapping]] = ..., bigDecimal: _Optional[_Union[BigDecimal, _Mapping]] = ...) -> None: ...

class Struct(_message.Message):
    __slots__ = ("members",)
    MEMBERS_FIELD_NUMBER: _ClassVar[int]
    members: _containers.RepeatedCompositeFieldContainer[RowData]
    def __init__(self, members: _Optional[_Iterable[_Union[RowData, _Mapping]]] = ...) -> None: ...

class Array(_message.Message):
    __slots__ = ("array",)
    ARRAY_FIELD_NUMBER: _ClassVar[int]
    array: _containers.RepeatedCompositeFieldContainer[RowData]
    def __init__(self, array: _Optional[_Iterable[_Union[RowData, _Mapping]]] = ...) -> None: ...

class Null(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class Date(_message.Message):
    __slots__ = ("timestamp", "timezoneOffsetMinutes")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TIMEZONEOFFSETMINUTES_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    timezoneOffsetMinutes: int
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., timezoneOffsetMinutes: _Optional[int] = ...) -> None: ...

class StreamDelimiter(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class BigInt(_message.Message):
    __slots__ = ("value", "endianness")
    VALUE_FIELD_NUMBER: _ClassVar[int]
    ENDIANNESS_FIELD_NUMBER: _ClassVar[int]
    value: bytes
    endianness: Endianness
    def __init__(self, value: _Optional[bytes] = ..., endianness: _Optional[_Union[Endianness, str]] = ...) -> None: ...

class BigDecimal(_message.Message):
    __slots__ = ("scale", "unscaledValue")
    SCALE_FIELD_NUMBER: _ClassVar[int]
    UNSCALEDVALUE_FIELD_NUMBER: _ClassVar[int]
    scale: int
    unscaledValue: BigInt
    def __init__(self, scale: _Optional[int] = ..., unscaledValue: _Optional[_Union[BigInt, _Mapping]] = ...) -> None: ...



from policy import policy_objects_pb2 as _policy_objects_pb2
from queryservice_client.protobuf.common import auth_pb2 as _auth_pb2
from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.common import error_pb2 as _error_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PolicySyncResponse(_message.Message):
    __slots__ = ("tableLink", "columnLink", "error")
    TABLELINK_FIELD_NUMBER: _ClassVar[int]
    COLUMNLINK_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    tableLink: _policy_objects_pb2.TableLink
    columnLink: _policy_objects_pb2.ColumnLink
    error: _error_pb2.Error
    def __init__(self, tableLink: _Optional[_Union[_policy_objects_pb2.TableLink, _Mapping]] = ..., columnLink: _Optional[_Union[_policy_objects_pb2.ColumnLink, _Mapping]] = ..., error: _Optional[_Union[_error_pb2.Error, _Mapping]] = ...) -> None: ...

class PolicySyncRequest(_message.Message):
    __slots__ = ("configuration", "auth", "policyApiId", "policyObjectSyncValues")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    POLICYAPIID_FIELD_NUMBER: _ClassVar[int]
    POLICYOBJECTSYNCVALUES_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    auth: _auth_pb2.Auth
    policyApiId: _policy_objects_pb2.PolicyApiId
    policyObjectSyncValues: _containers.RepeatedCompositeFieldContainer[_policy_objects_pb2.PolicyObjectSyncValue]
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., auth: _Optional[_Union[_auth_pb2.Auth, _Mapping]] = ..., policyApiId: _Optional[_Union[_policy_objects_pb2.PolicyApiId, _Mapping]] = ..., policyObjectSyncValues: _Optional[_Iterable[_Union[_policy_objects_pb2.PolicyObjectSyncValue, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dl/dl_elt.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from dl import dl_objects_pb2 as dl_dot_dl__objects__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as common_dot_extraction__objects__pb2
from asset import filter_extraction_pb2 as asset_dot_filter__extraction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x64l/dl_elt.proto\x12\nocf.dl.elt\x1a\x1a\x63ommon/configuration.proto\x1a\x13\x64l/dl_objects.proto\x1a\x16\x63ommon/job_error.proto\x1a\x1f\x63ommon/extraction_objects.proto\x1a\x1d\x61sset/filter_extraction.proto\"\xb0\x02\n\x18LineageExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x15\n\rhasAllLineage\x18\x02 \x01(\x08\x12\x30\n\rprojectDetail\x18\x03 \x03(\x0b\x32\x19.ocf.dl.elt.ProjectDetail\x12\x33\n\x08\x62ookmark\x18\x04 \x03(\x0b\x32!.extraction_objects.KeyedBookmark\x12\x45\n\x06\x66ilter\x18\x05 \x03(\x0b\x32\x35.ocf.asset.filter_extraction.FilterExtractionResponse\x12\x19\n\x11isInclusionFilter\x18\x06 \x01(\x08\"\x9e\x03\n\rProjectDetail\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nexternalId\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tabaseType\x18\x03 \x01(\t\x12\x45\n\x0e\x61\x64\x64itionalInfo\x18\x04 \x03(\x0b\x32-.ocf.dl.elt.ProjectDetail.AdditionalInfoEntry\x12W\n\x17\x64\x61tasourceConfiguration\x18\x05 \x03(\x0b\x32\x36.ocf.dl.elt.ProjectDetail.DatasourceConfigurationEntry\x12>\n\x14primaryConnectorInfo\x18\x06 \x01(\x0b\x32 .ocf.dl.elt.PrimaryConnectorInfo\x1a\x35\n\x13\x41\x64\x64itionalInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a>\n\x1c\x44\x61tasourceConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x14PrimaryConnectorInfo\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\x9b\x02\n\x19LineageExtractionResponse\x12\x41\n\x0blineagePath\x18\x01 \x01(\x0b\x32*.ocf.dl.direct_lineage_objects.LineagePathH\x00\x12\x35\n\x08\x62ookmark\x18\x02 \x01(\x0b\x32!.extraction_objects.KeyedBookmarkH\x00\x12!\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x12\x44\n\x12\x65xtractionProgress\x18\x04 \x01(\x0b\x32&.extraction_objects.ExtractionProgressH\x00\x42\x1b\n\x19LineageExtractionResponse2y\n\x11LineageExtraction\x12\x64\n\x11LineageExtraction\x12$.ocf.dl.elt.LineageExtractionRequest\x1a%.ocf.dl.elt.LineageExtractionResponse\"\x00\x30\x01\x42;\n\x1b\x61lation.sdk.ocf.dl.elt.grpcB\x1a\x45ltDirectLineageExtractionP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dl.dl_elt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.ocf.dl.elt.grpcB\032EltDirectLineageExtractionP\001'
  _globals['_PROJECTDETAIL_ADDITIONALINFOENTRY']._options = None
  _globals['_PROJECTDETAIL_ADDITIONALINFOENTRY']._serialized_options = b'8\001'
  _globals['_PROJECTDETAIL_DATASOURCECONFIGURATIONENTRY']._options = None
  _globals['_PROJECTDETAIL_DATASOURCECONFIGURATIONENTRY']._serialized_options = b'8\001'
  _globals['_LINEAGEEXTRACTIONREQUEST']._serialized_start=169
  _globals['_LINEAGEEXTRACTIONREQUEST']._serialized_end=473
  _globals['_PROJECTDETAIL']._serialized_start=476
  _globals['_PROJECTDETAIL']._serialized_end=890
  _globals['_PROJECTDETAIL_ADDITIONALINFOENTRY']._serialized_start=773
  _globals['_PROJECTDETAIL_ADDITIONALINFOENTRY']._serialized_end=826
  _globals['_PROJECTDETAIL_DATASOURCECONFIGURATIONENTRY']._serialized_start=828
  _globals['_PROJECTDETAIL_DATASOURCECONFIGURATIONENTRY']._serialized_end=890
  _globals['_PRIMARYCONNECTORINFO']._serialized_start=892
  _globals['_PRIMARYCONNECTORINFO']._serialized_end=942
  _globals['_LINEAGEEXTRACTIONRESPONSE']._serialized_start=945
  _globals['_LINEAGEEXTRACTIONRESPONSE']._serialized_end=1228
  _globals['_LINEAGEEXTRACTION']._serialized_start=1230
  _globals['_LINEAGEEXTRACTION']._serialized_end=1351
# @@protoc_insertion_point(module_scope)



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CheckStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SUCCESS: _ClassVar[CheckStatus]
    FAILURE: _ClassVar[CheckStatus]
    SKIPPED: _ClassVar[CheckStatus]
    WARNING: _ClassVar[CheckStatus]
SUCCESS: CheckStatus
FAILURE: CheckStatus
SKIPPED: CheckStatus
WARNING: CheckStatus

class CheckRequest(_message.Message):
    __slots__ = ("configuration", "check_name", "check_ids")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    CHECK_NAME_FIELD_NUMBER: _ClassVar[int]
    CHECK_IDS_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    check_name: str
    check_ids: _containers.RepeatedCompositeFieldContainer[CheckID]
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., check_name: _Optional[str] = ..., check_ids: _Optional[_Iterable[_Union[CheckID, _Mapping]]] = ...) -> None: ...

class CheckID(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class CheckResult(_message.Message):
    __slots__ = ("id", "result", "error", "message")
    ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    id: str
    result: CheckStatus
    error: CheckError
    message: CheckMessage
    def __init__(self, id: _Optional[str] = ..., result: _Optional[_Union[CheckStatus, str]] = ..., error: _Optional[_Union[CheckError, _Mapping]] = ..., message: _Optional[_Union[CheckMessage, _Mapping]] = ...) -> None: ...

class CheckError(_message.Message):
    __slots__ = ("error_code", "error_text", "action")
    ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_TEXT_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    error_code: str
    error_text: str
    action: str
    def __init__(self, error_code: _Optional[str] = ..., error_text: _Optional[str] = ..., action: _Optional[str] = ...) -> None: ...

class CheckMessage(_message.Message):
    __slots__ = ("text", "action")
    TEXT_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    text: str
    action: str
    def __init__(self, text: _Optional[str] = ..., action: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from queryservice_client.protobuf.common import verify_pb2 as common_dot_verify__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as rdbms_dot_mde__pb2
from queryservice_client.protobuf.rdbms import profiling_pb2 as rdbms_dot_profiling__pb2
from queryservice_client.protobuf.rdbms import qle_pb2 as rdbms_dot_qle__pb2
from queryservice_client.protobuf.rdbms import query_pb2 as rdbms_dot_query__pb2


class RdbmsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigurationVerification = channel.unary_unary(
                '/rdbms.Rdbms/ConfigurationVerification',
                request_serializer=common_dot_verify__pb2.Request.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.FilterExtraction = channel.unary_stream(
                '/rdbms.Rdbms/FilterExtraction',
                request_serializer=rdbms_dot_mde__pb2.FilterExtractionRequest.SerializeToString,
                response_deserializer=rdbms_dot_mde__pb2.FilterExtractionResponse.FromString,
                )
        self.MetadataExtraction = channel.unary_stream(
                '/rdbms.Rdbms/MetadataExtraction',
                request_serializer=rdbms_dot_mde__pb2.MetadataExtractionRequest.SerializeToString,
                response_deserializer=rdbms_dot_mde__pb2.MetadataExtractionResponse.FromString,
                )
        self.TableExtraction = channel.unary_stream(
                '/rdbms.Rdbms/TableExtraction',
                request_serializer=rdbms_dot_mde__pb2.TableExtractionRequest.SerializeToString,
                response_deserializer=rdbms_dot_mde__pb2.TableExtractionResponse.FromString,
                )
        self.QuerylogExtraction = channel.unary_stream(
                '/rdbms.Rdbms/QuerylogExtraction',
                request_serializer=rdbms_dot_qle__pb2.Request.SerializeToString,
                response_deserializer=rdbms_dot_qle__pb2.Response.FromString,
                )
        self.TableProfiling = channel.unary_stream(
                '/rdbms.Rdbms/TableProfiling',
                request_serializer=rdbms_dot_profiling__pb2.TableProfilingRequest.SerializeToString,
                response_deserializer=rdbms_dot_profiling__pb2.TableProfilingResponse.FromString,
                )
        self.ColumnProfiling = channel.unary_stream(
                '/rdbms.Rdbms/ColumnProfiling',
                request_serializer=rdbms_dot_profiling__pb2.ColumnProfilingRequest.SerializeToString,
                response_deserializer=rdbms_dot_profiling__pb2.ColumnProfilingResponse.FromString,
                )
        self.CustomTableProfiling = channel.unary_stream(
                '/rdbms.Rdbms/CustomTableProfiling',
                request_serializer=rdbms_dot_profiling__pb2.CustomTableProfilingRequest.SerializeToString,
                response_deserializer=rdbms_dot_profiling__pb2.CustomTableProfilingResponse.FromString,
                )
        self.CustomColumnProfiling = channel.unary_stream(
                '/rdbms.Rdbms/CustomColumnProfiling',
                request_serializer=rdbms_dot_profiling__pb2.CustomColumnProfilingRequest.SerializeToString,
                response_deserializer=rdbms_dot_profiling__pb2.ColumnProfilingResponse.FromString,
                )
        self.StartSession = channel.unary_unary(
                '/rdbms.Rdbms/StartSession',
                request_serializer=rdbms_dot_query__pb2.StartSessionRequest.SerializeToString,
                response_deserializer=rdbms_dot_query__pb2.StartSessionResponse.FromString,
                )
        self.EndSession = channel.unary_unary(
                '/rdbms.Rdbms/EndSession',
                request_serializer=rdbms_dot_query__pb2.EndSessionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Query = channel.unary_stream(
                '/rdbms.Rdbms/Query',
                request_serializer=rdbms_dot_query__pb2.QueryRequest.SerializeToString,
                response_deserializer=rdbms_dot_query__pb2.QueryResponse.FromString,
                )
        self.CancelQuery = channel.unary_unary(
                '/rdbms.Rdbms/CancelQuery',
                request_serializer=rdbms_dot_query__pb2.CancelQueryRequest.SerializeToString,
                response_deserializer=rdbms_dot_query__pb2.CancelQueryResponse.FromString,
                )


class RdbmsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConfigurationVerification(self, request, context):
        """Verify that the connector has been configured correctly.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FilterExtraction(self, request, context):
        """Retrieve all objects that can be used to filter metadata extraction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MetadataExtraction(self, request, context):
        """Run full or selective extraction extraction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TableExtraction(self, request, context):
        """Retrieve metadata for a single Table.
        This method is called as a downstream step to a user running a DDL statement on Compose.
        If the connector does not support Compose, then this method does not need to be implemented.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuerylogExtraction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TableProfiling(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ColumnProfiling(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CustomTableProfiling(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CustomColumnProfiling(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EndSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Query(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RdbmsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigurationVerification': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigurationVerification,
                    request_deserializer=common_dot_verify__pb2.Request.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'FilterExtraction': grpc.unary_stream_rpc_method_handler(
                    servicer.FilterExtraction,
                    request_deserializer=rdbms_dot_mde__pb2.FilterExtractionRequest.FromString,
                    response_serializer=rdbms_dot_mde__pb2.FilterExtractionResponse.SerializeToString,
            ),
            'MetadataExtraction': grpc.unary_stream_rpc_method_handler(
                    servicer.MetadataExtraction,
                    request_deserializer=rdbms_dot_mde__pb2.MetadataExtractionRequest.FromString,
                    response_serializer=rdbms_dot_mde__pb2.MetadataExtractionResponse.SerializeToString,
            ),
            'TableExtraction': grpc.unary_stream_rpc_method_handler(
                    servicer.TableExtraction,
                    request_deserializer=rdbms_dot_mde__pb2.TableExtractionRequest.FromString,
                    response_serializer=rdbms_dot_mde__pb2.TableExtractionResponse.SerializeToString,
            ),
            'QuerylogExtraction': grpc.unary_stream_rpc_method_handler(
                    servicer.QuerylogExtraction,
                    request_deserializer=rdbms_dot_qle__pb2.Request.FromString,
                    response_serializer=rdbms_dot_qle__pb2.Response.SerializeToString,
            ),
            'TableProfiling': grpc.unary_stream_rpc_method_handler(
                    servicer.TableProfiling,
                    request_deserializer=rdbms_dot_profiling__pb2.TableProfilingRequest.FromString,
                    response_serializer=rdbms_dot_profiling__pb2.TableProfilingResponse.SerializeToString,
            ),
            'ColumnProfiling': grpc.unary_stream_rpc_method_handler(
                    servicer.ColumnProfiling,
                    request_deserializer=rdbms_dot_profiling__pb2.ColumnProfilingRequest.FromString,
                    response_serializer=rdbms_dot_profiling__pb2.ColumnProfilingResponse.SerializeToString,
            ),
            'CustomTableProfiling': grpc.unary_stream_rpc_method_handler(
                    servicer.CustomTableProfiling,
                    request_deserializer=rdbms_dot_profiling__pb2.CustomTableProfilingRequest.FromString,
                    response_serializer=rdbms_dot_profiling__pb2.CustomTableProfilingResponse.SerializeToString,
            ),
            'CustomColumnProfiling': grpc.unary_stream_rpc_method_handler(
                    servicer.CustomColumnProfiling,
                    request_deserializer=rdbms_dot_profiling__pb2.CustomColumnProfilingRequest.FromString,
                    response_serializer=rdbms_dot_profiling__pb2.ColumnProfilingResponse.SerializeToString,
            ),
            'StartSession': grpc.unary_unary_rpc_method_handler(
                    servicer.StartSession,
                    request_deserializer=rdbms_dot_query__pb2.StartSessionRequest.FromString,
                    response_serializer=rdbms_dot_query__pb2.StartSessionResponse.SerializeToString,
            ),
            'EndSession': grpc.unary_unary_rpc_method_handler(
                    servicer.EndSession,
                    request_deserializer=rdbms_dot_query__pb2.EndSessionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Query': grpc.unary_stream_rpc_method_handler(
                    servicer.Query,
                    request_deserializer=rdbms_dot_query__pb2.QueryRequest.FromString,
                    response_serializer=rdbms_dot_query__pb2.QueryResponse.SerializeToString,
            ),
            'CancelQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelQuery,
                    request_deserializer=rdbms_dot_query__pb2.CancelQueryRequest.FromString,
                    response_serializer=rdbms_dot_query__pb2.CancelQueryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'rdbms.Rdbms', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Rdbms(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConfigurationVerification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rdbms.Rdbms/ConfigurationVerification',
            common_dot_verify__pb2.Request.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FilterExtraction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rdbms.Rdbms/FilterExtraction',
            rdbms_dot_mde__pb2.FilterExtractionRequest.SerializeToString,
            rdbms_dot_mde__pb2.FilterExtractionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MetadataExtraction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rdbms.Rdbms/MetadataExtraction',
            rdbms_dot_mde__pb2.MetadataExtractionRequest.SerializeToString,
            rdbms_dot_mde__pb2.MetadataExtractionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TableExtraction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rdbms.Rdbms/TableExtraction',
            rdbms_dot_mde__pb2.TableExtractionRequest.SerializeToString,
            rdbms_dot_mde__pb2.TableExtractionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QuerylogExtraction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rdbms.Rdbms/QuerylogExtraction',
            rdbms_dot_qle__pb2.Request.SerializeToString,
            rdbms_dot_qle__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TableProfiling(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rdbms.Rdbms/TableProfiling',
            rdbms_dot_profiling__pb2.TableProfilingRequest.SerializeToString,
            rdbms_dot_profiling__pb2.TableProfilingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ColumnProfiling(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rdbms.Rdbms/ColumnProfiling',
            rdbms_dot_profiling__pb2.ColumnProfilingRequest.SerializeToString,
            rdbms_dot_profiling__pb2.ColumnProfilingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CustomTableProfiling(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rdbms.Rdbms/CustomTableProfiling',
            rdbms_dot_profiling__pb2.CustomTableProfilingRequest.SerializeToString,
            rdbms_dot_profiling__pb2.CustomTableProfilingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CustomColumnProfiling(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rdbms.Rdbms/CustomColumnProfiling',
            rdbms_dot_profiling__pb2.CustomColumnProfilingRequest.SerializeToString,
            rdbms_dot_profiling__pb2.ColumnProfilingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rdbms.Rdbms/StartSession',
            rdbms_dot_query__pb2.StartSessionRequest.SerializeToString,
            rdbms_dot_query__pb2.StartSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EndSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rdbms.Rdbms/EndSession',
            rdbms_dot_query__pb2.EndSessionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Query(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/rdbms.Rdbms/Query',
            rdbms_dot_query__pb2.QueryRequest.SerializeToString,
            rdbms_dot_query__pb2.QueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/rdbms.Rdbms/CancelQuery',
            rdbms_dot_query__pb2.CancelQueryRequest.SerializeToString,
            rdbms_dot_query__pb2.CancelQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



class Column:
    def __init__(self, name, label, type, ordinality, dtype):
        self.name = name
        self.label = label
        self.type = type
        self.ordinality = ordinality
        self.dtype = dtype

    @classmethod
    def from_projection(cls, projection):
        return cls(projection.name, projection.label, projection.type, projection.ordinality, projection.dtype)

    def __str__(self):
        return f"Column(name='{self.name}', label='{self.label}', type='{self.type}', ordinality={self.ordinality}, dtype={self.dtype})"

    def __eq__(self, other):
        if isinstance(other, Column):
            return (self.name == other.name and self.label == other.label and
                    self.type == other.type and self.ordinality == other.ordinality and
                    self.dtype == other.dtype)
        return False

    def __hash__(self):
        return hash((self.name, self.label, self.type, self.ordinality, self.dtype))


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset/mde_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61sset/mde_objects.proto\x12\x15ocf.asset.mde_objects\x1a\x1cgoogle/protobuf/struct.proto\"\xa3\x01\n\x05\x41sset\x12.\n\x03\x65id\x18\x01 \x01(\x0b\x32!.ocf.asset.mde_objects.ExternalID\x12\x35\n\nparent_eid\x18\x02 \x01(\x0b\x32!.ocf.asset.mde_objects.ExternalID\x12\x33\n\nproperties\x18\x65 \x03(\x0b\x32\x1f.ocf.asset.mde_objects.Property\"?\n\nExternalID\x12\x10\n\x08\x61type_id\x18\x01 \x01(\t\x12\x12\n\natype_name\x18\x02 \x01(\t\x12\x0b\n\x03\x65id\x18\x03 \x01(\t\".\n\x10RelationMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"\xc4\x02\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x10relationMetadata\x18\x02 \x01(\x0b\x32\'.ocf.asset.mde_objects.RelationMetadata\x12\x12\n\x08string_v\x18\x64 \x01(\tH\x00\x12,\n\x06list_v\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x00\x12\x11\n\x07int32_v\x18\x66 \x01(\x05H\x00\x12\x11\n\x07int64_v\x18g \x01(\x03H\x00\x12\x10\n\x06\x62ool_v\x18h \x01(\x08H\x00\x12\x30\n\x07\x61sset_v\x18\xc8\x01 \x01(\x0b\x32\x1c.ocf.asset.mde_objects.AssetH\x00\x12\x32\n\x08\x61ssets_v\x18\xc9\x01 \x01(\x0b\x32\x1d.ocf.asset.mde_objects.AssetsH\x00\x42\x07\n\x05value\"6\n\x06\x41ssets\x12,\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x1c.ocf.asset.mde_objects.Asset\"\x99\x02\n\x0e\x44QRuleAndValue\x12\x12\n\nexternalID\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12+\n\x05\x61sset\x18\x05 \x01(\x0b\x32\x1c.ocf.asset.mde_objects.Asset\x12/\n\x06status\x18\x06 \x01(\x0e\x32\x1f.ocf.asset.mde_objects.DQStatus\x12\x12\n\x08string_v\x18\x64 \x01(\tH\x00\x12\x11\n\x07int32_v\x18\x65 \x01(\x05H\x00\x12\x10\n\x06\x62ool_v\x18\x66 \x01(\x08H\x00\x12\x0b\n\x03url\x18\x07 \x01(\t\x12\x15\n\rlastUpdatedAt\x18\x08 \x01(\tB\x07\n\x05value*,\n\x08\x44QStatus\x12\x08\n\x04GOOD\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x12\t\n\x05\x41LERT\x10\x02\x42\x42\n\x1a\x61lation.sdk.asset.grpc.mdeB\x0fMetadataObjectsP\x01Z\x11\x61sset/mde_objectsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset.mde_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032alation.sdk.asset.grpc.mdeB\017MetadataObjectsP\001Z\021asset/mde_objects'
  _globals['_DQSTATUS']._serialized_start=1026
  _globals['_DQSTATUS']._serialized_end=1070
  _globals['_ASSET']._serialized_start=81
  _globals['_ASSET']._serialized_end=244
  _globals['_EXTERNALID']._serialized_start=246
  _globals['_EXTERNALID']._serialized_end=309
  _globals['_RELATIONMETADATA']._serialized_start=311
  _globals['_RELATIONMETADATA']._serialized_end=357
  _globals['_PROPERTY']._serialized_start=360
  _globals['_PROPERTY']._serialized_end=684
  _globals['_ASSETS']._serialized_start=686
  _globals['_ASSETS']._serialized_end=740
  _globals['_DQRULEANDVALUE']._serialized_start=743
  _globals['_DQRULEANDVALUE']._serialized_end=1024
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: servicediscovery/servicediscovery.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'servicediscovery/servicediscovery.proto\x12\x10servicediscovery\"\x15\n\x05\x41gent\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"\x1c\n\tProxyList\x12\x0f\n\x07proxies\x18\x01 \x03(\t2d\n\x15ProxyServiceDiscovery\x12K\n\x11ResolveProxiesFor\x12\x17.servicediscovery.Agent\x1a\x1b.servicediscovery.ProxyList\"\x00\x42=\n\'alation.sdk.ocf.system.servicediscoveryB\x10ServiceDiscoveryP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'servicediscovery.servicediscovery_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'alation.sdk.ocf.system.servicediscoveryB\020ServiceDiscoveryP\001'
  _globals['_AGENT']._serialized_start=61
  _globals['_AGENT']._serialized_end=82
  _globals['_PROXYLIST']._serialized_start=84
  _globals['_PROXYLIST']._serialized_end=112
  _globals['_PROXYSERVICEDISCOVERY']._serialized_start=114
  _globals['_PROXYSERVICEDISCOVERY']._serialized_end=214
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset/filter_extraction_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%asset/filter_extraction_objects.proto\x12#ocf.asset.filter_extraction_objects\"\xe6\x01\n\x06\x46ilter\x12\x13\n\x0b\x65xternal_id\x18\x01 \x01(\t\x12\x37\n\x04path\x18\x02 \x01(\x0b\x32).ocf.asset.filter_extraction_objects.Path\x12W\n\x0e\x61\x64\x64itionalInfo\x18\x03 \x03(\x0b\x32?.ocf.asset.filter_extraction_objects.Filter.AdditionalInfoEntry\x1a\x35\n\x13\x41\x64\x64itionalInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x04Path\x12\x0c\n\x04path\x18\x01 \x03(\t\x12\x11\n\tdelimiter\x18\x02 \x01(\tBf\n(alation.sdk.asset.grpc.filter_extractionB\x17\x46ilterExtractionObjectsP\x01Z\x1f\x61sset/filter_extraction_objectsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset.filter_extraction_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(alation.sdk.asset.grpc.filter_extractionB\027FilterExtractionObjectsP\001Z\037asset/filter_extraction_objects'
  _globals['_FILTER_ADDITIONALINFOENTRY']._options = None
  _globals['_FILTER_ADDITIONALINFOENTRY']._serialized_options = b'8\001'
  _globals['_FILTER']._serialized_start=79
  _globals['_FILTER']._serialized_end=309
  _globals['_FILTER_ADDITIONALINFOENTRY']._serialized_start=256
  _globals['_FILTER_ADDITIONALINFOENTRY']._serialized_end=309
  _globals['_PATH']._serialized_start=311
  _globals['_PATH']._serialized_end=350
# @@protoc_insertion_point(module_scope)



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from asset import filter_extraction_objects_pb2 as _filter_extraction_objects_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FilterExtractionRequest(_message.Message):
    __slots__ = ("configuration",)
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ...) -> None: ...

class FilterExtractionResponse(_message.Message):
    __slots__ = ("filter",)
    FILTER_FIELD_NUMBER: _ClassVar[int]
    filter: _filter_extraction_objects_pb2.Filter
    def __init__(self, filter: _Optional[_Union[_filter_extraction_objects_pb2.Filter, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dl/dl_rdbms.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dl import dl_objects_pb2 as dl_dot_dl__objects__pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as rdbms_dot_mde__pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as common_dot_extraction__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64l/dl_rdbms.proto\x12\x0cocf.dl.rdbms\x1a\x13\x64l/dl_objects.proto\x1a\x0frdbms/mde.proto\x1a\x17rdbms/mde_objects.proto\x1a\x1a\x63ommon/configuration.proto\x1a\x1f\x63ommon/extraction_objects.proto\"\xcb\x01\n\x18LineageExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12.\n\tschemaIds\x18\x02 \x03(\x0b\x32\x1b.rdbms.mde_objects.SchemaId\x12\x19\n\x11is_include_filter\x18\x03 \x01(\x08\x12.\n\x08\x62ookmark\x18\x04 \x01(\x0b\x32\x1c.extraction_objects.Bookmark\"\x98\x01\n\x19LineageExtractionResponse\x12\x41\n\x0blineagePath\x18\x02 \x01(\x0b\x32*.ocf.dl.direct_lineage_objects.LineagePathH\x00\x12\x30\n\x08\x62ookmark\x18\x03 \x01(\x0b\x32\x1c.extraction_objects.BookmarkH\x00\x42\x06\n\x04\x64\x61ta2~\n\x12RdbmsDirectLineage\x12h\n\x11LineageExtraction\x12&.ocf.dl.rdbms.LineageExtractionRequest\x1a\'.ocf.dl.rdbms.LineageExtractionResponse\"\x00\x30\x01\x42\x34\n\x17\x61lation.sdk.ocf.dl.grpcB\x17\x44irectLineageExtractionP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dl.dl_rdbms_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.ocf.dl.grpcB\027DirectLineageExtractionP\001'
  _globals['_LINEAGEEXTRACTIONREQUEST']._serialized_start=160
  _globals['_LINEAGEEXTRACTIONREQUEST']._serialized_end=363
  _globals['_LINEAGEEXTRACTIONRESPONSE']._serialized_start=366
  _globals['_LINEAGEEXTRACTIONRESPONSE']._serialized_end=518
  _globals['_RDBMSDIRECTLINEAGE']._serialized_start=520
  _globals['_RDBMSDIRECTLINEAGE']._serialized_end=646
# @@protoc_insertion_point(module_scope)



from cf import cf_objects_pb2 as _cf_objects_pb2
from queryservice_client.protobuf.common import auth_pb2 as _auth_pb2
from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.common import error_pb2 as _error_pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as _mde_objects_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CustomFieldSyncResponse(_message.Message):
    __slots__ = ("schemaId", "tableId", "columnId", "error")
    SCHEMAID_FIELD_NUMBER: _ClassVar[int]
    TABLEID_FIELD_NUMBER: _ClassVar[int]
    COLUMNID_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    schemaId: _mde_objects_pb2.SchemaId
    tableId: _mde_objects_pb2.TableId
    columnId: _mde_objects_pb2.ColumnId
    error: _error_pb2.Error
    def __init__(self, schemaId: _Optional[_Union[_mde_objects_pb2.SchemaId, _Mapping]] = ..., tableId: _Optional[_Union[_mde_objects_pb2.TableId, _Mapping]] = ..., columnId: _Optional[_Union[_mde_objects_pb2.ColumnId, _Mapping]] = ..., error: _Optional[_Union[_error_pb2.Error, _Mapping]] = ...) -> None: ...

class CustomFieldSyncRequest(_message.Message):
    __slots__ = ("configuration", "auth", "customFieldValueUpdates")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    AUTH_FIELD_NUMBER: _ClassVar[int]
    CUSTOMFIELDVALUEUPDATES_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    auth: _auth_pb2.Auth
    customFieldValueUpdates: _containers.RepeatedCompositeFieldContainer[_cf_objects_pb2.CustomFieldValueUpdate]
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., auth: _Optional[_Union[_auth_pb2.Auth, _Mapping]] = ..., customFieldValueUpdates: _Optional[_Iterable[_Union[_cf_objects_pb2.CustomFieldValueUpdate, _Mapping]]] = ...) -> None: ...



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as _extraction_objects_pb2
from queryservice_client.protobuf.common import job_error_pb2 as _job_error_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectExtractionRequest(_message.Message):
    __slots__ = ("configuration",)
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ...) -> None: ...

class ProjectExtractionResponse(_message.Message):
    __slots__ = ("Project", "extractionProgress", "error")
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    EXTRACTIONPROGRESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    Project: Project
    extractionProgress: _extraction_objects_pb2.ExtractionProgress
    error: _job_error_pb2.Error
    def __init__(self, Project: _Optional[_Union[Project, _Mapping]] = ..., extractionProgress: _Optional[_Union[_extraction_objects_pb2.ExtractionProgress, _Mapping]] = ..., error: _Optional[_Union[_job_error_pb2.Error, _Mapping]] = ...) -> None: ...

class Project(_message.Message):
    __slots__ = ("externalId", "name", "databaseType", "lineageInfo", "hostInfo", "additionalInfo")
    class AdditionalInfoEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    EXTERNALID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DATABASETYPE_FIELD_NUMBER: _ClassVar[int]
    LINEAGEINFO_FIELD_NUMBER: _ClassVar[int]
    HOSTINFO_FIELD_NUMBER: _ClassVar[int]
    ADDITIONALINFO_FIELD_NUMBER: _ClassVar[int]
    externalId: str
    name: str
    databaseType: str
    lineageInfo: LineageInfo
    hostInfo: HostInfo
    additionalInfo: _containers.ScalarMap[str, str]
    def __init__(self, externalId: _Optional[str] = ..., name: _Optional[str] = ..., databaseType: _Optional[str] = ..., lineageInfo: _Optional[_Union[LineageInfo, _Mapping]] = ..., hostInfo: _Optional[_Union[HostInfo, _Mapping]] = ..., additionalInfo: _Optional[_Mapping[str, str]] = ...) -> None: ...

class LineageInfo(_message.Message):
    __slots__ = ("primaryConnectorName", "hasAllLineage", "hasLineage")
    PRIMARYCONNECTORNAME_FIELD_NUMBER: _ClassVar[int]
    HASALLLINEAGE_FIELD_NUMBER: _ClassVar[int]
    HASLINEAGE_FIELD_NUMBER: _ClassVar[int]
    primaryConnectorName: str
    hasAllLineage: bool
    hasLineage: bool
    def __init__(self, primaryConnectorName: _Optional[str] = ..., hasAllLineage: bool = ..., hasLineage: bool = ...) -> None: ...

class HostInfo(_message.Message):
    __slots__ = ("host", "port")
    HOST_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    host: str
    port: int
    def __init__(self, host: _Optional[str] = ..., port: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/auth.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63ommon/auth.proto\x12\x04\x61uth\x1a\x1bgoogle/protobuf/empty.proto\"\xc2\x02\n\x04\x41uth\x12&\n\x04none\x18\x64 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x1e\n\x06simple\x18\x65 \x01(\x0b\x32\x0c.auth.SimpleH\x00\x12\x1c\n\x05oauth\x18\x66 \x01(\x0b\x32\x0b.auth.OAuthH\x00\x12*\n\x0coauthRefresh\x18g \x01(\x0b\x32\x12.auth.OAuthRefreshH\x00\x12\"\n\x08\x61wsBasic\x18h \x01(\x0b\x32\x0e.auth.AwsBasicH\x00\x12&\n\nawsSession\x18i \x01(\x0b\x32\x10.auth.AwsSessionH\x00\x12&\n\nazureBasic\x18j \x01(\x0b\x32\x10.auth.AzureBasicH\x00\x12\'\n\x0crefreshToken\x18\x84\x07 \x01(\x0b\x32\x10.auth.CAGRequestB\x0b\n\tmechanism\",\n\x06Simple\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"L\n\x05OAuth\x12\x13\n\x0b\x61\x63\x63\x65ssToken\x18\x01 \x01(\t\x12\x11\n\texpiresIn\x18\x02 \x01(\x05\x12\x0e\n\x06\x65xpiry\x18\x03 \x01(\x03\x12\x0b\n\x03uri\x18\x04 \x01(\t\"L\n\x0cOAuthRefresh\x12\x14\n\x0crefreshToken\x18\x01 \x01(\t\x12\x10\n\x08\x63lientId\x18\x02 \x01(\t\x12\x14\n\x0c\x63lientSecret\x18\x03 \x01(\t\"0\n\x08\x41wsBasic\x12\x11\n\taccessKey\x18\x01 \x01(\t\x12\x11\n\tsecretKey\x18\x02 \x01(\t\"l\n\nAwsSession\x12\x11\n\taccessKey\x18\x01 \x01(\t\x12\x11\n\tsecretKey\x18\x02 \x01(\t\x12\x14\n\x0csessionToken\x18\x03 \x01(\t\x12\x12\n\ndbUserName\x18\x04 \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x05 \x01(\x03\".\n\nAzureBasic\x12\r\n\x05isSAS\x18\x01 \x01(\x08\x12\x11\n\taccessKey\x18\x02 \x01(\t\"F\n\nCAGRequest\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x17\n\x0f\x65\x61gerInitialize\x18\x03 \x01(\x08\x42=\n\x1c\x61lation.sdk.grpc.common.authB\x0e\x41uthenticationP\x01Z\x0b\x63ommon/authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034alation.sdk.grpc.common.authB\016AuthenticationP\001Z\013common/auth'
  _globals['_AUTH']._serialized_start=57
  _globals['_AUTH']._serialized_end=379
  _globals['_SIMPLE']._serialized_start=381
  _globals['_SIMPLE']._serialized_end=425
  _globals['_OAUTH']._serialized_start=427
  _globals['_OAUTH']._serialized_end=503
  _globals['_OAUTHREFRESH']._serialized_start=505
  _globals['_OAUTHREFRESH']._serialized_end=581
  _globals['_AWSBASIC']._serialized_start=583
  _globals['_AWSBASIC']._serialized_end=631
  _globals['_AWSSESSION']._serialized_start=633
  _globals['_AWSSESSION']._serialized_end=741
  _globals['_AZUREBASIC']._serialized_start=743
  _globals['_AZUREBASIC']._serialized_end=789
  _globals['_CAGREQUEST']._serialized_start=791
  _globals['_CAGREQUEST']._serialized_end=861
# @@protoc_insertion_point(module_scope)



class ImmutableList:
    def __init__(self):
        self.set([])

    def is_empty(self):
        return self.pointer == len(self.inner)

    def pop(self):
        value = self.inner[self.pointer]
        self.pointer += 1
        return value

    def set(self, inner):
        self.inner = inner
        self.pointer = 0
        return self


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dl/dl_elt_project_extraction.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as common_dot_extraction__objects__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dl/dl_elt_project_extraction.proto\x12\x19ocf.dl.project_extraction\x1a\x1a\x63ommon/configuration.proto\x1a\x1f\x63ommon/extraction_objects.proto\x1a\x16\x63ommon/job_error.proto\"P\n\x18ProjectExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\"\xd8\x01\n\x19ProjectExtractionResponse\x12\x35\n\x07Project\x18\x01 \x01(\x0b\x32\".ocf.dl.project_extraction.ProjectH\x00\x12\x44\n\x12\x65xtractionProgress\x18\x02 \x01(\x0b\x32&.extraction_objects.ExtractionProgressH\x00\x12!\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x1b\n\x19ProjectExtractionResponse\"\xbc\x02\n\x07Project\x12\x12\n\nexternalId\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tabaseType\x18\x03 \x01(\t\x12;\n\x0blineageInfo\x18\x04 \x01(\x0b\x32&.ocf.dl.project_extraction.LineageInfo\x12\x35\n\x08hostInfo\x18\x05 \x01(\x0b\x32#.ocf.dl.project_extraction.HostInfo\x12N\n\x0e\x61\x64\x64itionalInfo\x18\x06 \x03(\x0b\x32\x36.ocf.dl.project_extraction.Project.AdditionalInfoEntry\x1a\x35\n\x13\x41\x64\x64itionalInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\x0bLineageInfo\x12\x1c\n\x14primaryConnectorName\x18\x01 \x01(\t\x12\x15\n\rhasAllLineage\x18\x02 \x01(\x08\x12\x12\n\nhasLineage\x18\x03 \x01(\x08\"&\n\x08HostInfo\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x32\x98\x01\n\x11ProjectExtraction\x12\x82\x01\n\x11ProjectExtraction\x12\x33.ocf.dl.project_extraction.ProjectExtractionRequest\x1a\x34.ocf.dl.project_extraction.ProjectExtractionResponse\"\x00\x30\x01\x42\x34\n$alation.sdk.ocf.dl.elt.projects.grpcB\nEltProjectP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dl.dl_elt_project_extraction_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$alation.sdk.ocf.dl.elt.projects.grpcB\nEltProjectP\001'
  _globals['_PROJECT_ADDITIONALINFOENTRY']._options = None
  _globals['_PROJECT_ADDITIONALINFOENTRY']._serialized_options = b'8\001'
  _globals['_PROJECTEXTRACTIONREQUEST']._serialized_start=150
  _globals['_PROJECTEXTRACTIONREQUEST']._serialized_end=230
  _globals['_PROJECTEXTRACTIONRESPONSE']._serialized_start=233
  _globals['_PROJECTEXTRACTIONRESPONSE']._serialized_end=449
  _globals['_PROJECT']._serialized_start=452
  _globals['_PROJECT']._serialized_end=768
  _globals['_PROJECT_ADDITIONALINFOENTRY']._serialized_start=715
  _globals['_PROJECT_ADDITIONALINFOENTRY']._serialized_end=768
  _globals['_LINEAGEINFO']._serialized_start=770
  _globals['_LINEAGEINFO']._serialized_end=856
  _globals['_HOSTINFO']._serialized_start=858
  _globals['_HOSTINFO']._serialized_end=896
  _globals['_PROJECTEXTRACTION']._serialized_start=899
  _globals['_PROJECTEXTRACTION']._serialized_end=1051
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dl/dl_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2
from queryservice_client.protobuf.common import datasource_pb2 as common_dot_datasource__pb2
from asset import filter_extraction_objects_pb2 as asset_dot_filter__extraction__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x64l/dl_objects.proto\x12\x1docf.dl.direct_lineage_objects\x1a\x17rdbms/mde_objects.proto\x1a\x17\x63ommon/datasource.proto\x1a%asset/filter_extraction_objects.proto\"Z\n\x08\x44\x61taflow\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12=\n\x06\x66\x61\x63\x65ts\x18\x02 \x01(\x0b\x32-.ocf.dl.direct_lineage_objects.DataflowFacets\"\xd7\x02\n\x0cNativeObject\x12+\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32\x16.datasource.DataSource\x12\x30\n\tschema_id\x18\x02 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaIdH\x00\x12.\n\x08table_id\x18\x03 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableIdH\x00\x12\x30\n\tcolumn_id\x18\x04 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnIdH\x00\x12\x38\n\x07path_id\x18\x06 \x01(\x0b\x32%.ocf.dl.direct_lineage_objects.PathIdH\x00\x12?\n\x06\x66\x61\x63\x65ts\x18\x05 \x01(\x0b\x32/.ocf.dl.direct_lineage_objects.DatasourceFacetsB\x0b\n\tObjectKey\"_\n\rLineageObject\x12\x44\n\rnative_object\x18\x01 \x01(\x0b\x32+.ocf.dl.direct_lineage_objects.NativeObjectH\x00\x42\x08\n\x06Object\"\x88\x02\n\x0bLineagePath\x12=\n\x07sources\x18\x01 \x03(\x0b\x32,.ocf.dl.direct_lineage_objects.LineageObject\x12\x39\n\x08\x64\x61taflow\x18\x02 \x01(\x0b\x32\'.ocf.dl.direct_lineage_objects.Dataflow\x12<\n\x06target\x18\x03 \x01(\x0b\x32,.ocf.dl.direct_lineage_objects.LineageObject\x12\x41\n\x12\x66ullyQualifiedPath\x18\x04 \x01(\x0b\x32%.ocf.dl.direct_lineage_objects.PathId\"M\n\x0eModelTypeFacet\x12;\n\tmodelType\x18\x01 \x01(\x0e\x32(.ocf.dl.direct_lineage_objects.ModelType\"\x98\x01\n\x10\x44\x61tasourceFacets\x12\x45\n\x0emodelTypeFacet\x18\x01 \x01(\x0b\x32-.ocf.dl.direct_lineage_objects.ModelTypeFacet\x12=\n\nmodelFacet\x18\x02 \x01(\x0b\x32).ocf.dl.direct_lineage_objects.ModelFacet\"V\n\x06PathId\x12\x13\n\x0b\x65xternal_id\x18\x01 \x01(\t\x12\x37\n\x04path\x18\x02 \x01(\x0b\x32).ocf.asset.filter_extraction_objects.Path\"5\n\nModelFacet\x12\x12\n\nexternalId\x18\x01 \x01(\t\x12\x13\n\x0b\x63olumnNames\x18\x02 \x03(\t\"\x19\n\tCodeFacet\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"\'\n\x10\x45xternalURLFacet\x12\x13\n\x0b\x65xternalUrl\x18\x01 \x01(\t\"\'\n\x12\x44\x61taFlowGroupFacet\x12\x11\n\tgroupName\x18\x01 \x01(\t\"\xf7\x01\n\x0e\x44\x61taflowFacets\x12;\n\tcodeFacet\x18\x01 \x01(\x0b\x32(.ocf.dl.direct_lineage_objects.CodeFacet\x12M\n\x12\x64\x61taflowGroupFacet\x18\x02 \x01(\x0b\x32\x31.ocf.dl.direct_lineage_objects.DataFlowGroupFacet\x12I\n\x10\x65xternalURLFacet\x18\x03 \x01(\x0b\x32/.ocf.dl.direct_lineage_objects.ExternalURLFacet\x12\x0e\n\x06\x64\x62Type\x18\x04 \x01(\t*@\n\tModelType\x12\t\n\x05TABLE\x10\x00\x12\x08\n\x04VIEW\x10\x01\x12\x0f\n\x0bINCREMENTAL\x10\x02\x12\r\n\tEPHEMERAL\x10\x03\x42\x31\n\x17\x61lation.sdk.ocf.dl.grpcB\x14\x44irectLineageObjectsP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dl.dl_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.ocf.dl.grpcB\024DirectLineageObjectsP\001'
  _globals['_MODELTYPE']._serialized_start=1681
  _globals['_MODELTYPE']._serialized_end=1745
  _globals['_DATAFLOW']._serialized_start=143
  _globals['_DATAFLOW']._serialized_end=233
  _globals['_NATIVEOBJECT']._serialized_start=236
  _globals['_NATIVEOBJECT']._serialized_end=579
  _globals['_LINEAGEOBJECT']._serialized_start=581
  _globals['_LINEAGEOBJECT']._serialized_end=676
  _globals['_LINEAGEPATH']._serialized_start=679
  _globals['_LINEAGEPATH']._serialized_end=943
  _globals['_MODELTYPEFACET']._serialized_start=945
  _globals['_MODELTYPEFACET']._serialized_end=1022
  _globals['_DATASOURCEFACETS']._serialized_start=1025
  _globals['_DATASOURCEFACETS']._serialized_end=1177
  _globals['_PATHID']._serialized_start=1179
  _globals['_PATHID']._serialized_end=1265
  _globals['_MODELFACET']._serialized_start=1267
  _globals['_MODELFACET']._serialized_end=1320
  _globals['_CODEFACET']._serialized_start=1322
  _globals['_CODEFACET']._serialized_end=1347
  _globals['_EXTERNALURLFACET']._serialized_start=1349
  _globals['_EXTERNALURLFACET']._serialized_end=1388
  _globals['_DATAFLOWGROUPFACET']._serialized_start=1390
  _globals['_DATAFLOWGROUPFACET']._serialized_end=1429
  _globals['_DATAFLOWFACETS']._serialized_start=1432
  _globals['_DATAFLOWFACETS']._serialized_end=1679
# @@protoc_insertion_point(module_scope)



from queryservice_client.protobuf.common import configuration_pb2 as _configuration_pb2
from dl import dl_objects_pb2 as _dl_objects_pb2
from queryservice_client.protobuf.common import job_error_pb2 as _job_error_pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as _extraction_objects_pb2
from asset import filter_extraction_pb2 as _filter_extraction_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LineageExtractionRequest(_message.Message):
    __slots__ = ("configuration", "hasAllLineage", "projectDetail", "bookmark", "filter", "isInclusionFilter")
    CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    HASALLLINEAGE_FIELD_NUMBER: _ClassVar[int]
    PROJECTDETAIL_FIELD_NUMBER: _ClassVar[int]
    BOOKMARK_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ISINCLUSIONFILTER_FIELD_NUMBER: _ClassVar[int]
    configuration: _configuration_pb2.ProtobufConfiguration
    hasAllLineage: bool
    projectDetail: _containers.RepeatedCompositeFieldContainer[ProjectDetail]
    bookmark: _containers.RepeatedCompositeFieldContainer[_extraction_objects_pb2.KeyedBookmark]
    filter: _containers.RepeatedCompositeFieldContainer[_filter_extraction_pb2.FilterExtractionResponse]
    isInclusionFilter: bool
    def __init__(self, configuration: _Optional[_Union[_configuration_pb2.ProtobufConfiguration, _Mapping]] = ..., hasAllLineage: bool = ..., projectDetail: _Optional[_Iterable[_Union[ProjectDetail, _Mapping]]] = ..., bookmark: _Optional[_Iterable[_Union[_extraction_objects_pb2.KeyedBookmark, _Mapping]]] = ..., filter: _Optional[_Iterable[_Union[_filter_extraction_pb2.FilterExtractionResponse, _Mapping]]] = ..., isInclusionFilter: bool = ...) -> None: ...

class ProjectDetail(_message.Message):
    __slots__ = ("name", "externalId", "databaseType", "additionalInfo", "datasourceConfiguration", "primaryConnectorInfo")
    class AdditionalInfoEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class DatasourceConfigurationEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    EXTERNALID_FIELD_NUMBER: _ClassVar[int]
    DATABASETYPE_FIELD_NUMBER: _ClassVar[int]
    ADDITIONALINFO_FIELD_NUMBER: _ClassVar[int]
    DATASOURCECONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    PRIMARYCONNECTORINFO_FIELD_NUMBER: _ClassVar[int]
    name: str
    externalId: str
    databaseType: str
    additionalInfo: _containers.ScalarMap[str, str]
    datasourceConfiguration: _containers.ScalarMap[str, str]
    primaryConnectorInfo: PrimaryConnectorInfo
    def __init__(self, name: _Optional[str] = ..., externalId: _Optional[str] = ..., databaseType: _Optional[str] = ..., additionalInfo: _Optional[_Mapping[str, str]] = ..., datasourceConfiguration: _Optional[_Mapping[str, str]] = ..., primaryConnectorInfo: _Optional[_Union[PrimaryConnectorInfo, _Mapping]] = ...) -> None: ...

class PrimaryConnectorInfo(_message.Message):
    __slots__ = ("host", "port")
    HOST_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    host: str
    port: int
    def __init__(self, host: _Optional[str] = ..., port: _Optional[int] = ...) -> None: ...

class LineageExtractionResponse(_message.Message):
    __slots__ = ("lineagePath", "bookmark", "error", "extractionProgress")
    LINEAGEPATH_FIELD_NUMBER: _ClassVar[int]
    BOOKMARK_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    EXTRACTIONPROGRESS_FIELD_NUMBER: _ClassVar[int]
    lineagePath: _dl_objects_pb2.LineagePath
    bookmark: _extraction_objects_pb2.KeyedBookmark
    error: _job_error_pb2.Error
    extractionProgress: _extraction_objects_pb2.ExtractionProgress
    def __init__(self, lineagePath: _Optional[_Union[_dl_objects_pb2.LineagePath, _Mapping]] = ..., bookmark: _Optional[_Union[_extraction_objects_pb2.KeyedBookmark, _Mapping]] = ..., error: _Optional[_Union[_job_error_pb2.Error, _Mapping]] = ..., extractionProgress: _Optional[_Union[_extraction_objects_pb2.ExtractionProgress, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from queryservice_client.protobuf.common import checks_pb2 as common_dot_checks__pb2


class OperationsStub(object):
    """The Operations Service contains endpoints that are used to verify and inspect the operation of the
    connector. These can include various service checks, health checks, operational stats,
    test endpoints etc.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PreflightCheck = channel.unary_stream(
                '/ocf.common.Operations/PreflightCheck',
                request_serializer=common_dot_checks__pb2.CheckRequest.SerializeToString,
                response_deserializer=common_dot_checks__pb2.CheckResult.FromString,
                )


class OperationsServicer(object):
    """The Operations Service contains endpoints that are used to verify and inspect the operation of the
    connector. These can include various service checks, health checks, operational stats,
    test endpoints etc.
    """

    def PreflightCheck(self, request, context):
        """Is used to do various pre flight checks on features
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OperationsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'PreflightCheck': grpc.unary_stream_rpc_method_handler(
                    servicer.PreflightCheck,
                    request_deserializer=common_dot_checks__pb2.CheckRequest.FromString,
                    response_serializer=common_dot_checks__pb2.CheckResult.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ocf.common.Operations', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Operations(object):
    """The Operations Service contains endpoints that are used to verify and inspect the operation of the
    connector. These can include various service checks, health checks, operational stats,
    test endpoints etc.
    """

    @staticmethod
    def PreflightCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ocf.common.Operations/PreflightCheck',
            common_dot_checks__pb2.CheckRequest.SerializeToString,
            common_dot_checks__pb2.CheckResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from cf import cf_rdbms_pb2 as cf_dot_cf__rdbms__pb2


class RdbmsCustomFieldMDEStub(object):
    """The RdbmsCustomFieldMDE enables an RDBMS connector to extract custom fields about RDBMS objects.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CustomFieldExtraction = channel.unary_stream(
                '/ocf.cf.rdbms.RdbmsCustomFieldMDE/CustomFieldExtraction',
                request_serializer=cf_dot_cf__rdbms__pb2.CustomFieldExtractionRequest.SerializeToString,
                response_deserializer=cf_dot_cf__rdbms__pb2.CustomFieldExtractionResponse.FromString,
                )


class RdbmsCustomFieldMDEServicer(object):
    """The RdbmsCustomFieldMDE enables an RDBMS connector to extract custom fields about RDBMS objects.
    """

    def CustomFieldExtraction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RdbmsCustomFieldMDEServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CustomFieldExtraction': grpc.unary_stream_rpc_method_handler(
                    servicer.CustomFieldExtraction,
                    request_deserializer=cf_dot_cf__rdbms__pb2.CustomFieldExtractionRequest.FromString,
                    response_serializer=cf_dot_cf__rdbms__pb2.CustomFieldExtractionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ocf.cf.rdbms.RdbmsCustomFieldMDE', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RdbmsCustomFieldMDE(object):
    """The RdbmsCustomFieldMDE enables an RDBMS connector to extract custom fields about RDBMS objects.
    """

    @staticmethod
    def CustomFieldExtraction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ocf.cf.rdbms.RdbmsCustomFieldMDE/CustomFieldExtraction',
            cf_dot_cf__rdbms__pb2.CustomFieldExtractionRequest.SerializeToString,
            cf_dot_cf__rdbms__pb2.CustomFieldExtractionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/query.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11rdbms/query.proto\x12\x0brdbms.query\x1a\x1a\x63ommon/configuration.proto\x1a\x11\x63ommon/auth.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"o\n\x13StartSessionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\"\n\x0e\x61uthentication\x18\x02 \x01(\x0b\x32\n.auth.Auth\"G\n\x14StartSessionResponse\x12\x11\n\tsessionId\x18\x01 \x01(\x04\x12\x1c\n\x14supportsCancellation\x18\x02 \x01(\x08\"&\n\x11\x45ndSessionRequest\x12\x11\n\tsessionId\x18\x01 \x01(\x04\"\'\n\x12\x43\x61ncelQueryRequest\x12\x11\n\tsessionId\x18\x01 \x01(\x04\"\x15\n\x13\x43\x61ncelQueryResponse\"P\n\x0cQueryRequest\x12\x11\n\tsessionId\x18\x01 \x01(\x04\x12\r\n\x05query\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x0f\n\x07timeout\x18\x04 \x01(\x05\"t\n\rQueryResponse\x12\x11\n\x07restart\x18\x01 \x01(\x08H\x00\x12\x13\n\tcancelled\x18\x03 \x01(\x08H\x00\x12/\n\x0bqueryResult\x18\x02 \x01(\x0b\x32\x18.rdbms.query.QueryResultH\x00\x42\n\n\x08response\">\n\x0bQueryResult\x12/\n\x07objects\x18\x01 \x03(\x0b\x32\x1e.rdbms.query.QueryResultObject\"\x9f\x02\n\x11QueryResultObject\x12\'\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.rdbms.query.StreamDataH\x00\x12\x36\n\x0e\x62\x65ginResultSet\x18\x05 \x01(\x0b\x32\x1c.rdbms.query.StreamDelimiterH\x00\x12\x36\n\x0e\x65ndOfResultSet\x18\x02 \x01(\x0b\x32\x1c.rdbms.query.StreamDelimiterH\x00\x12\x35\n\rendOfMetadata\x18\x03 \x01(\x0b\x32\x1c.rdbms.query.StreamDelimiterH\x00\x12\x30\n\x08\x65ndOfRow\x18\x04 \x01(\x0b\x32\x1c.rdbms.query.StreamDelimiterH\x00\x42\x08\n\x06object\"h\n\nStreamData\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x15.rdbms.query.MetadataH\x00\x12\'\n\x07rowData\x18\x02 \x01(\x0b\x32\x14.rdbms.query.RowDataH\x00\x42\x06\n\x04\x64\x61ta\"\\\n\x08Metadata\x12-\n\nprojection\x18\x01 \x01(\x0b\x32\x17.rdbms.query.ProjectionH\x00\x12\x15\n\x0bupdateCount\x18\x02 \x01(\x03H\x00\x42\n\n\x08metadata\"q\n\nProjection\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nordinality\x18\x02 \x01(\x04\x12\x0c\n\x04type\x18\x03 \x01(\t\x12$\n\x05\x64type\x18\x04 \x01(\x0e\x32\x15.rdbms.query.DataType\x12\r\n\x05label\x18\x05 \x01(\t\"\x95\x03\n\x07RowData\x12!\n\x04null\x18\x01 \x01(\x0b\x32\x11.rdbms.query.NullH\x00\x12\x10\n\x06\x64ouble\x18\x02 \x01(\x01H\x00\x12\x0f\n\x05\x66loat\x18\x03 \x01(\x02H\x00\x12\x0f\n\x05int32\x18\x04 \x01(\x05H\x00\x12\x0f\n\x05int64\x18\x05 \x01(\x03H\x00\x12\x10\n\x06uint32\x18\x06 \x01(\rH\x00\x12\x10\n\x06uint64\x18\x07 \x01(\x04H\x00\x12\x0e\n\x04\x62ool\x18\x08 \x01(\x08H\x00\x12\x10\n\x06string\x18\t \x01(\tH\x00\x12\x0f\n\x05\x62ytes\x18\n \x01(\x0cH\x00\x12!\n\x04\x64\x61te\x18\x0b \x01(\x0b\x32\x11.rdbms.query.DateH\x00\x12#\n\x05\x61rray\x18\x0c \x01(\x0b\x32\x12.rdbms.query.ArrayH\x00\x12%\n\x06struct\x18\r \x01(\x0b\x32\x13.rdbms.query.StructH\x00\x12%\n\x06\x62igInt\x18\x0e \x01(\x0b\x32\x13.rdbms.query.BigIntH\x00\x12-\n\nbigDecimal\x18\x0f \x01(\x0b\x32\x17.rdbms.query.BigDecimalH\x00\x42\x06\n\x04\x64\x61ta\"/\n\x06Struct\x12%\n\x07members\x18\x01 \x03(\x0b\x32\x14.rdbms.query.RowData\",\n\x05\x41rray\x12#\n\x05\x61rray\x18\x01 \x03(\x0b\x32\x14.rdbms.query.RowData\"\x06\n\x04Null\"T\n\x04\x44\x61te\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15timezoneOffsetMinutes\x18\x02 \x01(\x03\"\x11\n\x0fStreamDelimiter\"D\n\x06\x42igInt\x12\r\n\x05value\x18\x01 \x01(\x0c\x12+\n\nendianness\x18\x02 \x01(\x0e\x32\x17.rdbms.query.Endianness\"G\n\nBigDecimal\x12\r\n\x05scale\x18\x01 \x01(\x05\x12*\n\runscaledValue\x18\x02 \x01(\x0b\x32\x13.rdbms.query.BigInt*\xb7\x01\n\x08\x44\x61taType\x12\x08\n\x04NULL\x10\x00\x12\n\n\x06\x44OUBLE\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\t\n\x05INT32\x10\x03\x12\t\n\x05INT64\x10\x04\x12\n\n\x06UINT32\x10\x05\x12\n\n\x06UINT64\x10\x06\x12\x08\n\x04\x42OOL\x10\x07\x12\n\n\x06STRING\x10\x08\x12\t\n\x05\x42YTES\x10\t\x12\x08\n\x04\x44\x41TE\x10\n\x12\t\n\x05\x41RRAY\x10\x0b\x12\n\n\x06STRUCT\x10\x0c\x12\n\n\x06\x42IGINT\x10\r\x12\x0e\n\nBIGDECIMAL\x10\x0e*!\n\nEndianness\x12\x07\n\x03\x42IG\x10\x00\x12\n\n\x06LITTLE\x10\x01\x42\x45\n\x1c\x61lation.sdk.rdbms.grpc.queryB\x16RdbmsQueryServiceProtoP\x01Z\x0brdbms/queryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034alation.sdk.rdbms.grpc.queryB\026RdbmsQueryServiceProtoP\001Z\013rdbms/query'
  _globals['_DATATYPE']._serialized_start=2033
  _globals['_DATATYPE']._serialized_end=2216
  _globals['_ENDIANNESS']._serialized_start=2218
  _globals['_ENDIANNESS']._serialized_end=2251
  _globals['_STARTSESSIONREQUEST']._serialized_start=114
  _globals['_STARTSESSIONREQUEST']._serialized_end=225
  _globals['_STARTSESSIONRESPONSE']._serialized_start=227
  _globals['_STARTSESSIONRESPONSE']._serialized_end=298
  _globals['_ENDSESSIONREQUEST']._serialized_start=300
  _globals['_ENDSESSIONREQUEST']._serialized_end=338
  _globals['_CANCELQUERYREQUEST']._serialized_start=340
  _globals['_CANCELQUERYREQUEST']._serialized_end=379
  _globals['_CANCELQUERYRESPONSE']._serialized_start=381
  _globals['_CANCELQUERYRESPONSE']._serialized_end=402
  _globals['_QUERYREQUEST']._serialized_start=404
  _globals['_QUERYREQUEST']._serialized_end=484
  _globals['_QUERYRESPONSE']._serialized_start=486
  _globals['_QUERYRESPONSE']._serialized_end=602
  _globals['_QUERYRESULT']._serialized_start=604
  _globals['_QUERYRESULT']._serialized_end=666
  _globals['_QUERYRESULTOBJECT']._serialized_start=669
  _globals['_QUERYRESULTOBJECT']._serialized_end=956
  _globals['_STREAMDATA']._serialized_start=958
  _globals['_STREAMDATA']._serialized_end=1062
  _globals['_METADATA']._serialized_start=1064
  _globals['_METADATA']._serialized_end=1156
  _globals['_PROJECTION']._serialized_start=1158
  _globals['_PROJECTION']._serialized_end=1271
  _globals['_ROWDATA']._serialized_start=1274
  _globals['_ROWDATA']._serialized_end=1679
  _globals['_STRUCT']._serialized_start=1681
  _globals['_STRUCT']._serialized_end=1728
  _globals['_ARRAY']._serialized_start=1730
  _globals['_ARRAY']._serialized_end=1774
  _globals['_NULL']._serialized_start=1776
  _globals['_NULL']._serialized_end=1782
  _globals['_DATE']._serialized_start=1784
  _globals['_DATE']._serialized_end=1868
  _globals['_STREAMDELIMITER']._serialized_start=1870
  _globals['_STREAMDELIMITER']._serialized_end=1887
  _globals['_BIGINT']._serialized_start=1889
  _globals['_BIGINT']._serialized_end=1957
  _globals['_BIGDECIMAL']._serialized_start=1959
  _globals['_BIGDECIMAL']._serialized_end=2030
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/verify.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ommon/verify.proto\x12\x06verify\x1a\x1a\x63ommon/configuration.proto\x1a\x11\x63ommon/auth.proto\"j\n\x07Request\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x18\n\x04\x61uth\x18\x02 \x01(\x0b\x32\n.auth.Auth\x12\x0f\n\x07jdbcUri\x18\x03 \x01(\tB9\n\x1e\x61lation.sdk.grpc.common.verifyB\x06VerifyP\x01Z\rcommon/verifyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.verify_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036alation.sdk.grpc.common.verifyB\006VerifyP\001Z\rcommon/verify'
  _globals['_REQUEST']._serialized_start=78
  _globals['_REQUEST']._serialized_end=184
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bi/certify.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from bi import mde_objects_pb2 as bi_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x62i/certify.proto\x12\nbi.certify\x1a\x1a\x63ommon/configuration.proto\x1a\x14\x62i/mde_objects.proto\"\xa3\x01\n\x1dPropagateCertificationRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12-\n\x08\x62iObject\x18\x02 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\x0c\n\x04note\x18\x03 \x01(\t\x12\x0f\n\x07\x63\x65rtify\x18\x04 \x01(\x08\x42\x37\n\x1b\x61lation.sdk.bi.grpc.certifyB\x16PropagateCertificationP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bi.certify_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.bi.grpc.certifyB\026PropagateCertificationP\001'
  _globals['_PROPAGATECERTIFICATIONREQUEST']._serialized_start=83
  _globals['_PROPAGATECERTIFICATIONREQUEST']._serialized_end=246
# @@protoc_insertion_point(module_scope)
